# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 19.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class LandingPage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'stac_version': 'str',
        'stac_extensions': 'list[str]',
        'type': 'str',
        'id': 'str',
        'title': 'str',
        'description': 'str',
        'links': 'list[StacLink]',
        'conforms_to': 'list[str]'
    }

    attribute_map = {
        'stac_version': 'stac_version',
        'stac_extensions': 'stac_extensions',
        'type': 'type',
        'id': 'id',
        'title': 'title',
        'description': 'description',
        'links': 'links',
        'conforms_to': 'conformsTo'
    }

    def __init__(self, stac_version=None, stac_extensions=None, type=None, id=None, title=None, description=None, links=None, conforms_to=None):  # noqa: E501
        """LandingPage - a model defined in Swagger"""  # noqa: E501

        self._stac_version = None
        self._stac_extensions = None
        self._type = None
        self._id = None
        self._title = None
        self._description = None
        self._links = None
        self._conforms_to = None
        self.discriminator = None

        self.stac_version = stac_version
        if stac_extensions is not None:
            self.stac_extensions = stac_extensions
        self.type = type
        self.id = id
        if title is not None:
            self.title = title
        self.description = description
        self.links = links
        self.conforms_to = conforms_to

    @property
    def stac_version(self):
        """Gets the stac_version of this LandingPage.  # noqa: E501


        :return: The stac_version of this LandingPage.  # noqa: E501
        :rtype: str
        """
        return self._stac_version

    @stac_version.setter
    def stac_version(self, stac_version):
        """Sets the stac_version of this LandingPage.


        :param stac_version: The stac_version of this LandingPage.  # noqa: E501
        :type: str
        """
        if stac_version is None:
            raise ValueError("Invalid value for `stac_version`, must not be `None`")  # noqa: E501

        self._stac_version = stac_version

    @property
    def stac_extensions(self):
        """Gets the stac_extensions of this LandingPage.  # noqa: E501


        :return: The stac_extensions of this LandingPage.  # noqa: E501
        :rtype: list[str]
        """
        return self._stac_extensions

    @stac_extensions.setter
    def stac_extensions(self, stac_extensions):
        """Sets the stac_extensions of this LandingPage.


        :param stac_extensions: The stac_extensions of this LandingPage.  # noqa: E501
        :type: list[str]
        """

        self._stac_extensions = stac_extensions

    @property
    def type(self):
        """Gets the type of this LandingPage.  # noqa: E501


        :return: The type of this LandingPage.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LandingPage.


        :param type: The type of this LandingPage.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def id(self):
        """Gets the id of this LandingPage.  # noqa: E501


        :return: The id of this LandingPage.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LandingPage.


        :param id: The id of this LandingPage.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def title(self):
        """Gets the title of this LandingPage.  # noqa: E501


        :return: The title of this LandingPage.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this LandingPage.


        :param title: The title of this LandingPage.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def description(self):
        """Gets the description of this LandingPage.  # noqa: E501


        :return: The description of this LandingPage.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this LandingPage.


        :param description: The description of this LandingPage.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def links(self):
        """Gets the links of this LandingPage.  # noqa: E501


        :return: The links of this LandingPage.  # noqa: E501
        :rtype: list[StacLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this LandingPage.


        :param links: The links of this LandingPage.  # noqa: E501
        :type: list[StacLink]
        """
        if links is None:
            raise ValueError("Invalid value for `links`, must not be `None`")  # noqa: E501

        self._links = links

    @property
    def conforms_to(self):
        """Gets the conforms_to of this LandingPage.  # noqa: E501

        A list of all conformance classes implemented by the server. In addition to the STAC-specific conformance classes, all OGC-related conformance classes listed at `GET /conformances` must be listed here. This entry should mirror what `GET /conformances` returns, if implemented.  # noqa: E501

        :return: The conforms_to of this LandingPage.  # noqa: E501
        :rtype: list[str]
        """
        return self._conforms_to

    @conforms_to.setter
    def conforms_to(self, conforms_to):
        """Sets the conforms_to of this LandingPage.

        A list of all conformance classes implemented by the server. In addition to the STAC-specific conformance classes, all OGC-related conformance classes listed at `GET /conformances` must be listed here. This entry should mirror what `GET /conformances` returns, if implemented.  # noqa: E501

        :param conforms_to: The conforms_to of this LandingPage.  # noqa: E501
        :type: list[str]
        """
        if conforms_to is None:
            raise ValueError("Invalid value for `conforms_to`, must not be `None`")  # noqa: E501

        self._conforms_to = conforms_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LandingPage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LandingPage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
